==> sugarcrm-2.5.1b_1.tbz: www/sugarcrm/modules/iFrames/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/

$mod_strings = array(
'LBL_MODULE_NAME' => 'Portal',
'LBL_MODULE_TITLE' => 'Portal: Home',
'LBL_LIST_STATUS'=>'Visible',
'LBL_LIST_NAME'=>'Name',
'LBL_LIST_URL'=>'Website',
'LBL_LIST_TYPE'=>'Type',
'LBL_LIST_CREATED_BY'=>'Created By',
'LBL_LIST_PLACEMENT'=>'Placement',
'LBL_LIST_FORM_TITLE' => 'Portal List',
'LBL_ADD_SITE' => 'Add Site',
'LBL_LIST_SITES' => 'List Sites',
'DEFAULT_URL' => 'http://www.sugarcrm.com',
'DROPDOWN_PLACEMENT'=>array(
							'all' => 'Tab Menu and Shortcut Menu',
							'tab' => 'Tab Menu',
							'shortcut'=>'Shortcut Menu',
							),
'DROPDOWN_TYPE'=>array(
							'personal' => 'Personal',
							'global' => 'Global',
							),
);
?>

==> sugarcrm-3.5.1.tbz: www/sugarcrm/modules/iFrames/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004-2005 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/

$mod_strings = array(
'LBL_MODULE_NAME' => 'Portal',
'LBL_MODULE_TITLE' => 'Portal: Home',
'LBL_LIST_STATUS'=>'Visible',
'LBL_LIST_NAME'=>'Name',
'LBL_LIST_URL'=>'Website',
'LBL_LIST_TYPE'=>'Type',
'LBL_LIST_CREATED_BY'=>'Created by',
'LBL_LIST_PLACEMENT'=>'Placement',
'LBL_LIST_FORM_TITLE' => 'Portal List',
'LBL_ADD_SITE' => 'Add Site',
'LBL_LIST_SITES' => 'List Sites',
'LBL_ID' => 'ID',
'DEFAULT_URL' => 'http://www.sugarcrm.com',
'DROPDOWN_PLACEMENT'=>array(
							'all' => 'Tab Menu and Shortcut Menu',
							'tab' => 'Tab Menu',
							'shortcut'=>'Shortcut Menu',
							),
'DROPDOWN_TYPE'=>array(
							'personal' => 'Personal',
							'global' => 'Global',
							),
);
?>
